#!/usr/bin/env bash
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

if [ -z "$1" ]; then
	echo "Need environment to execute script, exiting..."
	exit 1
fi

if [[ ! "$1" =~ ^(localdev|dev08|dev01|test03|eap01|prod01|prod02|prod04|prod05|prod06|prodnrt|prodsyd)$ ]]; then
    echo "$1 is not an environment, exiting..."
    exit 1
fi

ENVIRONMENT=$1
CUSTOM_SUBROLES_UPDATES=""
SERVICE_CONNECTORS_ARG=""
MIGRATE_ONLY_ARG=""
GREEN_ONLY_ARG=""
CSP_ARG=""

while (( "$#" )); do
  case "$2" in
    --service-connectors)
	  SERVICE_CONNECTORS_ARG="--service-connectors"
      shift 1
      ;;
    --csp)
	  CSP_ARG="-csp"
      shift 1
      ;;
    --migrate-only)
	  MIGRATE_ONLY_ARG="--migrate-only"
      shift 1
      ;;
    --migration-plan)
	  MIGRATION_PLAN_ARG="--migration-plan"
      shift 1
      ;;
    --green-only)
	  GREEN_ONLY_ARG="--green-only"
      shift 1
      ;;
    --custom-subroles-updates)
	  CUSTOM_SUBROLES_UPDATES="--custom-subroles-updates"
      shift 1
      ;;
    --)
      shift
      break
      ;;
    -*|--*=) # unsupported flags
      echo "Error: Unsupported flag $2" >&2
      exit 1
      ;;
 	*)
      shift
      ;;
  esac
done


echo "Beginning RBAC Migration on environment: " ${ENVIRONMENT}

# Create Python Virtual Env and install required packages
virtualenv -p python3 venv3

if [ -d "venv3" ]; then
    . venv3/bin/activate
    echo "Installing pip requirements..."
    pip install -r requirements.txt
else
    exit 1
fi

python migration_manager.py -e ${ENVIRONMENT} ${GREEN_ONLY_ARG} ${CSP_ARG} ${SERVICE_CONNECTORS_ARG} ${MIGRATE_ONLY_ARG} ${MIGRATION_PLAN_ARG} ${CUSTOM_SUBROLES_UPDATES}
